c           life time in s
        real*8  t0pi, t0k, t0mu, t0ks, t0kl, t0pi0, t0d0, t0dc
        real*8  t0sigmap, t0sigmam, t0sigma0, t0gzai0, t0gzaim
        real*8  t0lambda, t0lambdac, t0eta, t0bomega

c           decay width in GeV
        real*8  wrho, womega, wphai

       parameter (
     1  t0pi=2.603d-8, t0k=1.2371d-8, t0mu=2.197d-6,
     2  t0ks=8.923d-11, t0kl=5.183d-8,
     3  t0pi0=8.4d-17, t0d0=4.2d-13, t0dc=1.06d-12  )
        parameter (
     1  t0sigmap = 0.8d-10,
     2  t0sigma0 = 5.8d-20,
     3  t0sigmam = 1.482d-10,
     4  t0gzai0 = 2.9d-10,
     5  t0gzaim = 1.641d-10,
     6  t0lambda = 2.623d-10,
     7  t0lambdac = 2.3d-13,
     8  t0eta     = 7.5d-19,
     9  t0bomega  = 0.822d-10 )

       parameter (
     4  wrho=150.d-3, womega=8.4d-3,
     5  wphai=4.4d-3    )

